@@ -18,12 +18,11 @@ logger = logging.getLogger("core_website_app.rest.contact_message.views")
 
 
 class ContactMessageList(APIView):
-    """ Create or get all Contact Message
-    """
+    """Create or get all Contact Message"""
 
     @method_decorator(api_staff_member_required())
     def get(self, request):
-        """ Get all Contact Message
+        """Get all Contact Message
 
         Args:
 
@@ -45,11 +44,11 @@ class ContactMessageList(APIView):
             # Return response
             return Response(serializer.data, status=status.HTTP_200_OK)
         except Exception as api_exception:
-            content = {'message': str(api_exception)}
+            content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
     def post(self, request):
-        """ Create a message
+        """Create a message
 
         Parameters:
 
@@ -85,19 +84,18 @@ class ContactMessageList(APIView):
             # Return the serialized message
             return Response(serializer.data, status=status.HTTP_201_CREATED)
         except ValidationError as validation_exception:
-            content = {'message': validation_exception.detail}
+            content = {"message": validation_exception.detail}
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except Exception as api_exception:
-            content = {'message': str(api_exception)}
+            content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
 
 class ContactMessageDetail(APIView):
-    """ Get or delete a Contact Message
-    """
+    """Get or delete a Contact Message"""
 
     def get_object(self, pk):
-        """ Get Contact Message from db
+        """Get Contact Message from db
 
         Args:
 
@@ -114,7 +112,7 @@ class ContactMessageDetail(APIView):
 
     @method_decorator(api_staff_member_required())
     def get(self, request, pk):
-        """ Retrieve a Contact Message
+        """Retrieve a Contact Message
 
         Parameters:
 
@@ -146,15 +144,15 @@ class ContactMessageDetail(APIView):
             # Return response
             return Response(serializer.data)
         except Http404:
-            content = {'message': 'Contact message not found.'}
+            content = {"message": "Contact message not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
         except Exception as api_exception:
-            content = {'message': str(api_exception)}
+            content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
     @method_decorator(api_staff_member_required())
     def delete(self, request, pk):
-        """ Delete a Contact Message
+        """Delete a Contact Message
 
         Parameters:
 
@@ -186,8 +184,8 @@ class ContactMessageDetail(APIView):
             # Return response
             return Response(status=status.HTTP_204_NO_CONTENT)
         except Http404:
-            content = {'message': 'Data not found.'}
+            content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
         except Exception as api_exception:
-            content = {'message': str(api_exception)}
+            content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
