@@ -12,32 +12,37 @@ from core_website_app.commons.enums import WEB_PAGE_TYPES
 
 
 class TestsWebPageApiGet(TestCase):
-
-    @patch.object(WebPage, 'get_by_type')
+    @patch.object(WebPage, "get_by_type")
     def test_web_page_get_policy_privacy(self, mock_get_web_page_by_type):
         # Arrange
         content = "content web page privacy"
-        mock_get_web_page_by_type.return_value = _create_mock_web_page(WEB_PAGE_TYPES["privacy_policy"], content)
+        mock_get_web_page_by_type.return_value = _create_mock_web_page(
+            WEB_PAGE_TYPES["privacy_policy"], content
+        )
         # Act
         result = web_page_api.get("privacy_policy")
         # Assert
         self.assertEqual("content web page privacy", result.content)
 
-    @patch.object(WebPage, 'get_by_type')
+    @patch.object(WebPage, "get_by_type")
     def test_web_page_get_term_of_use(self, mock_get_web_page_by_type):
         # Arrange
         content = "content web page terms"
-        mock_get_web_page_by_type.return_value = _create_mock_web_page(WEB_PAGE_TYPES["terms_of_use"], content)
+        mock_get_web_page_by_type.return_value = _create_mock_web_page(
+            WEB_PAGE_TYPES["terms_of_use"], content
+        )
         # Act
         result = web_page_api.get("terms_of_use")
         # Assert
         self.assertEqual("content web page terms", result.content)
 
-    @patch.object(WebPage, 'get_by_type')
+    @patch.object(WebPage, "get_by_type")
     def test_web_page_get_help(self, mock_get_web_page_by_type):
         # Arrange
         content = "content web page help"
-        mock_get_web_page_by_type.return_value = _create_mock_web_page(WEB_PAGE_TYPES["help"], content)
+        mock_get_web_page_by_type.return_value = _create_mock_web_page(
+            WEB_PAGE_TYPES["help"], content
+        )
         # Act
         result = web_page_api.get("help")
         # Assert
@@ -58,7 +63,6 @@ class TestsWebPageApiGet(TestCase):
 
 
 class TestsWebPageApiUpsert(TestCase):
-
     def test_web_page_upsert_type_does_not_exist(self):
         # Arrange
         web_page = WebPage(5, "test")
@@ -66,7 +70,7 @@ class TestsWebPageApiUpsert(TestCase):
         with self.assertRaises(ApiError):
             web_page_api.upsert(web_page)
 
-    @patch.object(WebPage, 'save')
+    @patch.object(WebPage, "save")
     def test_web_page_upsert_type_exist(self, mock_save):
         # Arrange
         web_page_type = WEB_PAGE_TYPES["help"]
